@@ -281,7 +281,6 @@ class Circuit(PrimaryModel, StatusModel):
     "graphql",
     "locations",
     "relationships",
-    "statuses",
     "webhooks",
 )
 class CircuitTermination(PrimaryModel, PathEndpoint, CableTermination):
@@ -371,6 +370,6 @@ class CircuitTermination(PrimaryModel, PathEndpoint, CableTermination):
     def get_peer_termination(self):
         peer_side = "Z" if self.term_side == "A" else "A"
         try:
-            return CircuitTermination.objects.prefetch_related("site").get(circuit=self.circuit, term_side=peer_side)
+            return CircuitTermination.objects.select_related("site").get(circuit=self.circuit, term_side=peer_side)
         except CircuitTermination.DoesNotExist:
             return None
