@@ -8,7 +8,7 @@ from nautobot.circuits.filters import (
 from nautobot.circuits.models import Circuit, CircuitTermination, CircuitType, Provider, ProviderNetwork
 from nautobot.dcim.models import Cable, Device, DeviceRole, DeviceType, Interface, Manufacturer, Region, Site
 from nautobot.extras.models import Status
-from nautobot.tenancy.models import Tenant, TenantGroup
+from nautobot.tenancy.models import Tenant
 from nautobot.utilities.testing import FilterTestCases
 
 
@@ -33,14 +33,11 @@ class ProviderTestCase(FilterTestCases.NameSlugFilterTestCase):
             ),
         )
 
-        regions = (
-            Region.objects.create(name="Test Region 1", slug="test-region-1"),
-            Region.objects.create(name="Test Region 2", slug="test-region-2"),
-        )
+        cls.regions = list(Region.objects.filter(sites__isnull=False, children__isnull=True, parent__isnull=True)[:2])
 
-        sites = (
-            Site.objects.create(name="Test Site 1", slug="test-site-1", region=regions[0]),
-            Site.objects.create(name="Test Site 2", slug="test-site-2", region=regions[1]),
+        cls.sites = (
+            Site.objects.filter(region=cls.regions[0]).first(),
+            Site.objects.filter(region=cls.regions[1]).first(),
         )
 
         circuit_types = (
@@ -53,8 +50,8 @@ class ProviderTestCase(FilterTestCases.NameSlugFilterTestCase):
             Circuit.objects.create(provider=providers[1], type=circuit_types[1], cid="Test Circuit 1"),
         )
 
-        CircuitTermination.objects.create(circuit=circuits[0], site=sites[0], term_side="A")
-        CircuitTermination.objects.create(circuit=circuits[1], site=sites[0], term_side="A")
+        CircuitTermination.objects.create(circuit=circuits[0], site=cls.sites[0], term_side="A")
+        CircuitTermination.objects.create(circuit=circuits[1], site=cls.sites[0], term_side="A")
 
     def test_asn(self):
         params = {"asn": ["65001", "65002"]}
@@ -65,17 +62,20 @@ class ProviderTestCase(FilterTestCases.NameSlugFilterTestCase):
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
     def test_site(self):
-        sites = Site.objects.all()[:2]
-        params = {"site_id": [sites[0].pk, sites[1].pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-        params = {"site": [sites[0].slug, sites[1].slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        filter_params = [
+            {"site_id": [self.sites[0].pk, self.sites[1].pk]},
+            {"site": [self.sites[0].pk, self.sites[1].slug]},
+        ]
+        for params in filter_params:
+            self.assertQuerysetEqualAndNotEmpty(
+                self.filterset(params, self.queryset).qs,
+                self.queryset.filter(circuits__terminations__site__in=[self.sites[0], self.sites[1]]).distinct(),
+            )
 
     def test_region(self):
-        regions = Region.objects.all()[:2]
-        params = {"region_id": [regions[0].pk, regions[1].pk]}
+        params = {"region_id": [self.regions[0].pk, self.regions[1].pk]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-        params = {"region": [regions[0].slug, regions[1].slug]}
+        params = {"region": [self.regions[0].slug, self.regions[1].slug]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
 
@@ -91,36 +91,23 @@ class CircuitTypeTestCase(FilterTestCases.NameSlugFilterTestCase):
         CircuitType.objects.create(name="Circuit Type 3", slug="circuit-type-3")
 
 
-class CircuitTestCase(FilterTestCases.FilterTestCase):
+class CircuitTestCase(FilterTestCases.FilterTestCase, FilterTestCases.TenancyFilterTestCaseMixin):
     queryset = Circuit.objects.all()
     filterset = CircuitFilterSet
+    tenancy_related_name = "circuits"
 
     @classmethod
     def setUpTestData(cls):
 
-        regions = (
-            Region.objects.create(name="Test Region 1", slug="test-region-1"),
-            Region.objects.create(name="Test Region 2", slug="test-region-2"),
-            Region.objects.create(name="Test Region 3", slug="test-region-3"),
+        cls.regions = list(Region.objects.filter(sites__isnull=False).distinct()[:3])
+
+        cls.sites = (
+            Site.objects.filter(region=cls.regions[0]).first(),
+            Site.objects.filter(region=cls.regions[1]).first(),
+            Site.objects.filter(region=cls.regions[2]).first(),
         )
 
-        sites = (
-            Site.objects.create(name="Test Site 1", slug="test-site-1", region=regions[0]),
-            Site.objects.create(name="Test Site 2", slug="test-site-2", region=regions[1]),
-            Site.objects.create(name="Test Site 3", slug="test-site-3", region=regions[2]),
-        )
-
-        tenant_groups = (
-            TenantGroup.objects.create(name="Tenant group 1", slug="tenant-group-1"),
-            TenantGroup.objects.create(name="Tenant group 2", slug="tenant-group-2"),
-            TenantGroup.objects.create(name="Tenant group 3", slug="tenant-group-3"),
-        )
-
-        tenants = (
-            Tenant.objects.create(name="Tenant 1", slug="tenant-1", group=tenant_groups[0]),
-            Tenant.objects.create(name="Tenant 2", slug="tenant-2", group=tenant_groups[1]),
-            Tenant.objects.create(name="Tenant 3", slug="tenant-3", group=tenant_groups[2]),
-        )
+        tenants = Tenant.objects.filter(group__isnull=False)
 
         circuit_types = (
             CircuitType.objects.create(name="Test Circuit Type 1", slug="test-circuit-type-1"),
@@ -199,9 +186,9 @@ class CircuitTestCase(FilterTestCases.FilterTestCase):
             ),
         )
 
-        CircuitTermination.objects.create(circuit=circuits[0], site=sites[0], term_side="A")
-        CircuitTermination.objects.create(circuit=circuits[1], site=sites[1], term_side="A")
-        CircuitTermination.objects.create(circuit=circuits[2], site=sites[2], term_side="A")
+        CircuitTermination.objects.create(circuit=circuits[0], site=cls.sites[0], term_side="A")
+        CircuitTermination.objects.create(circuit=circuits[1], site=cls.sites[1], term_side="A")
+        CircuitTermination.objects.create(circuit=circuits[2], site=cls.sites[2], term_side="A")
         CircuitTermination.objects.create(circuit=circuits[3], provider_network=provider_network[0], term_side="A")
         CircuitTermination.objects.create(circuit=circuits[4], provider_network=provider_network[1], term_side="A")
         CircuitTermination.objects.create(circuit=circuits[5], provider_network=provider_network[2], term_side="A")
@@ -219,11 +206,16 @@ class CircuitTestCase(FilterTestCases.FilterTestCase):
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
     def test_provider(self):
-        provider = Provider.objects.first()
-        params = {"provider_id": [provider.pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
-        params = {"provider": [provider.slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
+        providers = list(Provider.objects.all()[:2])
+        filter_params = [
+            {"provider_id": [providers[0].id, providers[1].id]},
+            {"provider": [providers[0].id, providers[1].slug]},
+        ]
+        for params in filter_params:
+            self.assertQuerysetEqualAndNotEmpty(
+                self.filterset(params, self.queryset).qs,
+                self.queryset.filter(provider__in=[providers[0], providers[1]]).distinct(),
+            )
 
     def test_provider_network(self):
         provider_network = ProviderNetwork.objects.all()[:2]
@@ -231,43 +223,45 @@ class CircuitTestCase(FilterTestCases.FilterTestCase):
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
     def test_type(self):
-        circuit_type = CircuitType.objects.first()
-        params = {"type_id": [circuit_type.pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
-        params = {"type": [circuit_type.slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 3)
+        circuit_types = list(CircuitType.objects.all()[:2])
+        filter_params = [
+            {"type_id": [circuit_types[0].pk, circuit_types[1].pk]},
+            {"type": [circuit_types[0].slug, circuit_types[1].pk]},
+        ]
+        for params in filter_params:
+            self.assertQuerysetEqualAndNotEmpty(
+                self.filterset(params, self.queryset).qs,
+                self.queryset.filter(type__in=[circuit_types[0], circuit_types[1]]).distinct(),
+            )
 
     def test_status(self):
-        params = {"status": ["active", "planned"]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 4)
+        statuses = list(Status.objects.get_for_model(Circuit)[:2])
+        params = {"status": [statuses[0].slug, statuses[1].slug]}
+        self.assertEqual(
+            self.filterset(params, self.queryset).qs.count(),
+            self.queryset.filter(status__slug__in=params["status"]).count(),
+        )
 
     def test_region(self):
-        regions = Region.objects.all()[:2]
-        params = {"region_id": [regions[0].pk, regions[1].pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-        params = {"region": [regions[0].slug, regions[1].slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        params = {"region_id": [self.regions[0].pk, self.regions[1].pk]}
+        cts = CircuitTermination.objects.filter(site__region__in=params["region_id"])
+        circuit_count = cts.values_list("circuit", flat=True).count()
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), circuit_count)
+        params = {"region": [self.regions[0].slug, self.regions[1].slug]}
+        cts = CircuitTermination.objects.filter(site__region__slug__in=params["region"])
+        circuit_count = cts.values_list("circuit", flat=True).count()
+        self.assertEqual(self.filterset(params, self.queryset).qs.count(), circuit_count)
 
     def test_site(self):
-        sites = Site.objects.all()[:2]
-        params = {"site_id": [sites[0].pk, sites[1].pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-        params = {"site": [sites[0].slug, sites[1].slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-
-    def test_tenant(self):
-        tenants = Tenant.objects.all()[:2]
-        params = {"tenant_id": [tenants[0].pk, tenants[1].pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 4)
-        params = {"tenant": [tenants[0].slug, tenants[1].slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 4)
-
-    def test_tenant_group(self):
-        tenant_groups = TenantGroup.objects.all()[:2]
-        params = {"tenant_group_id": [tenant_groups[0].pk, tenant_groups[1].pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 4)
-        params = {"tenant_group": [tenant_groups[0].slug, tenant_groups[1].slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 4)
+        filter_params = [
+            {"site_id": [self.sites[0].pk, self.sites[1].pk]},
+            {"site": [self.sites[0].slug, self.sites[1].pk]},
+        ]
+        for params in filter_params:
+            self.assertQuerysetEqualAndNotEmpty(
+                self.filterset(params, self.queryset).qs,
+                self.queryset.filter(terminations__site__in=[self.sites[0], self.sites[1]]).distinct(),
+            )
 
     def test_search(self):
         value = self.queryset.values_list("pk", flat=True)[0]
@@ -282,11 +276,7 @@ class CircuitTerminationTestCase(FilterTestCases.FilterTestCase):
     @classmethod
     def setUpTestData(cls):
 
-        sites = (
-            Site.objects.create(name="Site 1", slug="site-1"),
-            Site.objects.create(name="Site 2", slug="site-2"),
-            Site.objects.create(name="Site 3", slug="site-3"),
-        )
+        sites = Site.objects.all()
         manufacturer = Manufacturer.objects.create(name="Test Manufacturer 1", slug="test-manufacturer-1")
         devicetype = DeviceType.objects.create(
             manufacturer=manufacturer,
@@ -438,7 +428,7 @@ class CircuitTerminationTestCase(FilterTestCases.FilterTestCase):
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
 
     def test_site(self):
-        sites = Site.objects.all()[:2]
+        sites = Site.objects.all()
         params = {"site_id": [sites[0].pk, sites[1].pk]}
         self.assertEqual(self.filterset(params, self.queryset).qs.count(), 4)
         params = {"site": [sites[0].slug, sites[1].slug]}
@@ -477,8 +467,13 @@ class ProviderNetworkTestCase(FilterTestCases.NameSlugFilterTestCase):
         ProviderNetwork.objects.bulk_create(provider_networks)
 
     def test_provider(self):
-        providers = Provider.objects.all()[:2]
-        params = {"provider_id": [providers[0].pk, providers[1].pk]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
-        params = {"provider": [providers[0].slug, providers[1].slug]}
-        self.assertEqual(self.filterset(params, self.queryset).qs.count(), 2)
+        providers = list(Provider.objects.all()[:2])
+        filter_params = [
+            {"provider_id": [providers[0].pk, providers[1].pk]},
+            {"provider": [providers[0].slug, providers[1].id]},
+        ]
+        for params in filter_params:
+            self.assertQuerysetEqualAndNotEmpty(
+                self.filterset(params, self.queryset).qs,
+                self.queryset.filter(provider__in=[providers[0], providers[1]]).distinct(),
+            )
