@@ -1,11 +1,15 @@
 import json
 import logging
+import os
+from pathlib import Path
 
-from celery import Celery, shared_task
+from celery import Celery, shared_task, signals
 from celery.fixups.django import DjangoFixup
+from django.conf import settings
 from django.core.serializers.json import DjangoJSONEncoder
 from django.utils.module_loading import import_string
 from kombu.serialization import register
+from prometheus_client import CollectorRegistry, multiprocess, start_http_server
 
 logger = logging.getLogger(__name__)
 
@@ -39,6 +43,34 @@ DjangoFixup(app).install()
 app.autodiscover_tasks()
 
 
+@signals.worker_ready.connect()
+def setup_prometheus(**kwargs):
+    """This sets up an HTTP server to serve prometheus metrics from the celery workers."""
+    # Don't set up the server if the port is undefined
+    if not settings.CELERY_WORKER_PROMETHEUS_PORTS:
+        return
+
+    logger.info("Setting up prometheus metrics HTTP server for celery worker.")
+
+    # Ensure that the multiprocess coordination directory exists. Note that we explicitly don't clear this directory
+    # out because the worker might share its filesystem with the core app or another worker. The multiprocess
+    # mechanism from prometheus-client takes care of this.
+    multiprocess_coordination_directory = Path(os.environ["prometheus_multiproc_dir"])
+    multiprocess_coordination_directory.mkdir(parents=True, exist_ok=True)
+
+    # Set up the collector registry
+    registry = CollectorRegistry()
+    multiprocess.MultiProcessCollector(registry, path=multiprocess_coordination_directory)
+    for port in settings.CELERY_WORKER_PROMETHEUS_PORTS:
+        try:
+            start_http_server(port, registry=registry)
+            break
+        except OSError:
+            continue
+    else:
+        logger.warning("Cannot export Prometheus metrics from worker, no available ports in range.")
+
+
 class NautobotKombuJSONEncoder(DjangoJSONEncoder):
     """
     Custom json encoder based on DjangoJSONEncoder that serializes objects that implement
