@@ -1,5 +1,5 @@
 from django.conf import settings
-from django.core.checks import register, Error, Tags, Warning
+from django.core.checks import register, Error, Tags, Warning  # pylint: disable=redefined-builtin
 from django.core.exceptions import ValidationError
 from django.core.validators import URLValidator
 
@@ -40,6 +40,13 @@ W005 = Warning(
     obj=settings,
 )
 
+W006 = Warning(
+    "CACHEOPS_ENABLED is set to True but cacheops is no longer recommended in v1.5. It can still be used but may lead to "
+    "inaccurate data responses. Cacheops will be removed in a later release.",
+    id="nautobot.core.W006",
+    obj=settings,
+)
+
 
 class E006(Error):
     msg = "RQ_QUEUES must define at least the minimum set of required queues"
@@ -63,7 +70,7 @@ def check_object_permissions_backend(app_configs, **kwargs):
 
 @register(Tags.compatibility)
 def check_release_check_timeout(app_configs, **kwargs):
-    if settings.RELEASE_CHECK_TIMEOUT < 3600:
+    if hasattr(settings, "RELEASE_CHECK_TIMEOUT") and settings.RELEASE_CHECK_TIMEOUT < 3600:
         return [E003]
     return []
 
@@ -71,7 +78,7 @@ def check_release_check_timeout(app_configs, **kwargs):
 @register(Tags.compatibility)
 def check_release_check_url(app_configs, **kwargs):
     validator = URLValidator()
-    if settings.RELEASE_CHECK_URL:
+    if hasattr(settings, "RELEASE_CHECK_URL") and settings.RELEASE_CHECK_URL:
         try:
             validator(settings.RELEASE_CHECK_URL)
         except ValidationError:
@@ -108,3 +115,10 @@ def check_maintenance_mode(app_configs, **kwargs):
     if settings.MAINTENANCE_MODE and settings.SESSION_ENGINE == "django.contrib.sessions.backends.db":
         return [E005]
     return []
+
+
+@register(Tags.compatibility)
+def check_cacheops_enabled(app_configs, **kwargs):
+    if settings.CACHEOPS_ENABLED:
+        return [W006]
+    return []
