@@ -125,7 +125,6 @@ class PassThroughPortMixin:
         Return all CablePaths which traverse a given pass-through port.
         """
         obj = get_object_or_404(self.queryset, pk=pk)
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         cablepaths = CablePath.objects.filter(path__contains=obj).prefetch_related("origin", "destination")
         serializer = serializers.CablePathSerializer(cablepaths, context={"request": request}, many=True)
 
@@ -149,14 +148,17 @@ class RegionViewSet(NautobotModelViewSet):
 
 
 class SiteViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Site.objects.prefetch_related("region", "status", "tenant", "tags").annotate(
-        device_count=count_related(Device, "site"),
-        rack_count=count_related(Rack, "site"),
-        prefix_count=count_related(Prefix, "site"),
-        vlan_count=count_related(VLAN, "site"),
-        circuit_count=count_related(Circuit, "terminations__site"),
-        virtualmachine_count=count_related(VirtualMachine, "cluster__site"),
+    queryset = (
+        Site.objects.select_related("region", "status", "tenant")
+        .prefetch_related("tags")
+        .annotate(
+            device_count=count_related(Device, "site"),
+            rack_count=count_related(Rack, "site"),
+            prefix_count=count_related(Prefix, "site"),
+            vlan_count=count_related(VLAN, "site"),
+            circuit_count=count_related(Circuit, "terminations__site"),
+            virtualmachine_count=count_related(VirtualMachine, "cluster__site"),
+        )
     )
     serializer_class = serializers.SiteSerializer
     filterset_class = filters.SiteFilterSet
@@ -168,9 +170,7 @@ class SiteViewSet(StatusViewSetMixin, NautobotModelViewSet):
 
 
 class LocationTypeViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (content_types should remain
-    # prefetch because it is m2m)
-    queryset = LocationType.objects.prefetch_related("parent", "content_types")
+    queryset = LocationType.objects.select_related("parent").prefetch_related("content_types")
     serializer_class = serializers.LocationTypeSerializer
     filterset_class = filters.LocationTypeFilterSet
 
@@ -181,8 +181,7 @@ class LocationTypeViewSet(NautobotModelViewSet):
 
 
 class LocationViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Location.objects.prefetch_related("location_type", "parent", "site", "status")
+    queryset = Location.objects.select_related("location_type", "parent", "site", "status")
     serializer_class = serializers.LocationSerializer
     filterset_class = filters.LocationFilterSet
 
@@ -193,10 +192,9 @@ class LocationViewSet(StatusViewSetMixin, NautobotModelViewSet):
 
 
 class RackGroupViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
     queryset = RackGroup.objects.add_related_count(
         RackGroup.objects.all(), Rack, "group", "rack_count", cumulative=True
-    ).prefetch_related("site")
+    ).select_related("site")
     serializer_class = serializers.RackGroupSerializer
     filterset_class = filters.RackGroupFilterSet
 
@@ -218,10 +216,13 @@ class RackRoleViewSet(NautobotModelViewSet):
 
 
 class RackViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags because it is m2m)
-    queryset = Rack.objects.prefetch_related("site", "group__site", "status", "role", "tenant", "tags").annotate(
-        device_count=count_related(Device, "rack"),
-        powerfeed_count=count_related(PowerFeed, "rack"),
+    queryset = (
+        Rack.objects.select_related("site", "group__site", "status", "role", "tenant")
+        .prefetch_related("tags")
+        .annotate(
+            device_count=count_related(Device, "rack"),
+            powerfeed_count=count_related(PowerFeed, "rack"),
+        )
     )
     serializer_class = serializers.RackSerializer
     filterset_class = filters.RackFilterSet
@@ -283,8 +284,7 @@ class RackViewSet(StatusViewSetMixin, NautobotModelViewSet):
 
 
 class RackReservationViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = RackReservation.objects.prefetch_related("rack", "user", "tenant")
+    queryset = RackReservation.objects.select_related("rack", "user", "tenant")
     serializer_class = serializers.RackReservationSerializer
     filterset_class = filters.RackReservationFilterSet
 
@@ -314,9 +314,10 @@ class ManufacturerViewSet(NautobotModelViewSet):
 
 
 class DeviceTypeViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags because it is m2m)
-    queryset = DeviceType.objects.prefetch_related("manufacturer", "tags").annotate(
-        device_count=count_related(Device, "device_type")
+    queryset = (
+        DeviceType.objects.select_related("manufacturer")
+        .prefetch_related("tags")
+        .annotate(device_count=count_related(Device, "device_type"))
     )
     serializer_class = serializers.DeviceTypeSerializer
     filterset_class = filters.DeviceTypeFilterSet
@@ -330,57 +331,49 @@ class DeviceTypeViewSet(NautobotModelViewSet):
 
 
 class ConsolePortTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = ConsolePortTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = ConsolePortTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.ConsolePortTemplateSerializer
     filterset_class = filters.ConsolePortTemplateFilterSet
 
 
 class ConsoleServerPortTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = ConsoleServerPortTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = ConsoleServerPortTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.ConsoleServerPortTemplateSerializer
     filterset_class = filters.ConsoleServerPortTemplateFilterSet
 
 
 class PowerPortTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = PowerPortTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = PowerPortTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.PowerPortTemplateSerializer
     filterset_class = filters.PowerPortTemplateFilterSet
 
 
 class PowerOutletTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = PowerOutletTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = PowerOutletTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.PowerOutletTemplateSerializer
     filterset_class = filters.PowerOutletTemplateFilterSet
 
 
 class InterfaceTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = InterfaceTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = InterfaceTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.InterfaceTemplateSerializer
     filterset_class = filters.InterfaceTemplateFilterSet
 
 
 class FrontPortTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = FrontPortTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = FrontPortTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.FrontPortTemplateSerializer
     filterset_class = filters.FrontPortTemplateFilterSet
 
 
 class RearPortTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = RearPortTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = RearPortTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.RearPortTemplateSerializer
     filterset_class = filters.RearPortTemplateFilterSet
 
 
 class DeviceBayTemplateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = DeviceBayTemplate.objects.prefetch_related("device_type__manufacturer")
+    queryset = DeviceBayTemplate.objects.select_related("device_type__manufacturer")
     serializer_class = serializers.DeviceBayTemplateSerializer
     filterset_class = filters.DeviceBayTemplateFilterSet
 
@@ -419,8 +412,7 @@ class PlatformViewSet(NautobotModelViewSet):
 
 
 class DeviceViewSet(ConfigContextQuerySetMixin, StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (extap tags because it is m2m)
-    queryset = Device.objects.prefetch_related(
+    queryset = Device.objects.select_related(
         "device_type__manufacturer",
         "device_role",
         "tenant",
@@ -428,12 +420,11 @@ class DeviceViewSet(ConfigContextQuerySetMixin, StatusViewSetMixin, NautobotMode
         "site",
         "rack",
         "parent_bay",
-        "primary_ip4__nat_outside_list",
-        "primary_ip6__nat_outside_list",
+        "primary_ip4",
+        "primary_ip6",
         "virtual_chassis__master",
-        "tags",
         "status",
-    )
+    ).prefetch_related("tags", "primary_ip4__nat_outside_list", "primary_ip6__nat_outside_list")
     filterset_class = filters.DeviceFilterSet
 
     def get_serializer_class(self):
@@ -614,8 +605,9 @@ class DeviceViewSet(ConfigContextQuerySetMixin, StatusViewSetMixin, NautobotMode
 
 
 class ConsolePortViewSet(PathEndpointMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = ConsolePort.objects.prefetch_related("device", "_path__destination", "cable", "_cable_peer", "tags")
+    queryset = ConsolePort.objects.select_related("device", "cable").prefetch_related(
+        "_path__destination", "_cable_peer", "tags"
+    )
     serializer_class = serializers.ConsolePortSerializer
     filterset_class = filters.ConsolePortFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -623,9 +615,8 @@ class ConsolePortViewSet(PathEndpointMixin, NautobotModelViewSet):
 
 
 class ConsoleServerPortViewSet(PathEndpointMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = ConsoleServerPort.objects.prefetch_related(
-        "device", "_path__destination", "cable", "_cable_peer", "tags"
+    queryset = ConsoleServerPort.objects.select_related("device", "cable").prefetch_related(
+        "_path__destination", "_cable_peer", "tags"
     )
     serializer_class = serializers.ConsoleServerPortSerializer
     filterset_class = filters.ConsoleServerPortFilterSet
@@ -634,8 +625,9 @@ class ConsoleServerPortViewSet(PathEndpointMixin, NautobotModelViewSet):
 
 
 class PowerPortViewSet(PathEndpointMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = PowerPort.objects.prefetch_related("device", "_path__destination", "cable", "_cable_peer", "tags")
+    queryset = PowerPort.objects.select_related("device", "cable").prefetch_related(
+        "_path__destination", "_cable_peer", "tags"
+    )
     serializer_class = serializers.PowerPortSerializer
     filterset_class = filters.PowerPortFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -643,8 +635,9 @@ class PowerPortViewSet(PathEndpointMixin, NautobotModelViewSet):
 
 
 class PowerOutletViewSet(PathEndpointMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = PowerOutlet.objects.prefetch_related("device", "_path__destination", "cable", "_cable_peer", "tags")
+    queryset = PowerOutlet.objects.select_related("device", "cable").prefetch_related(
+        "_path__destination", "_cable_peer", "tags"
+    )
     serializer_class = serializers.PowerOutletSerializer
     filterset_class = filters.PowerOutletFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -665,19 +658,14 @@ class PowerOutletViewSet(PathEndpointMixin, NautobotModelViewSet):
     update=extend_schema(responses={"200": serializers.InterfaceSerializerVersion12}, versions=["1.2", "1.3"]),
 )
 class InterfaceViewSet(PathEndpointMixin, NautobotModelViewSet, StatusViewSetMixin):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = Interface.objects.prefetch_related(
+    queryset = Interface.objects.select_related(
         "device",
         "parent_interface",
         "bridge",
         "lag",
         "status",
-        "_path__destination",
         "cable",
-        "_cable_peer",
-        "ip_addresses",
-        "tags",
-    )
+    ).prefetch_related("tags", "_path__destination", "_cable_peer", "ip_addresses")
     serializer_class = serializers.InterfaceSerializer
     filterset_class = filters.InterfaceFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -695,8 +683,9 @@ class InterfaceViewSet(PathEndpointMixin, NautobotModelViewSet, StatusViewSetMix
 
 
 class FrontPortViewSet(PassThroughPortMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = FrontPort.objects.prefetch_related("device__device_type__manufacturer", "rear_port", "cable", "tags")
+    queryset = FrontPort.objects.select_related(
+        "device__device_type__manufacturer", "rear_port", "cable"
+    ).prefetch_related("tags")
     serializer_class = serializers.FrontPortSerializer
     filterset_class = filters.FrontPortFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -704,8 +693,7 @@ class FrontPortViewSet(PassThroughPortMixin, NautobotModelViewSet):
 
 
 class RearPortViewSet(PassThroughPortMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = RearPort.objects.prefetch_related("device__device_type__manufacturer", "cable", "tags")
+    queryset = RearPort.objects.select_related("device__device_type__manufacturer", "cable").prefetch_related("tags")
     serializer_class = serializers.RearPortSerializer
     filterset_class = filters.RearPortFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -713,8 +701,7 @@ class RearPortViewSet(PassThroughPortMixin, NautobotModelViewSet):
 
 
 class DeviceBayViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = DeviceBay.objects.prefetch_related("installed_device").prefetch_related("tags")
+    queryset = DeviceBay.objects.select_related("installed_device").prefetch_related("tags")
     serializer_class = serializers.DeviceBaySerializer
     filterset_class = filters.DeviceBayFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -722,8 +709,7 @@ class DeviceBayViewSet(NautobotModelViewSet):
 
 
 class InventoryItemViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = InventoryItem.objects.prefetch_related("device", "manufacturer").prefetch_related("tags")
+    queryset = InventoryItem.objects.select_related("device", "manufacturer").prefetch_related("tags")
     serializer_class = serializers.InventoryItemSerializer
     filterset_class = filters.InventoryItemFilterSet
     # v2 TODO(jathan): Replace prefetch_related with select_related
@@ -736,22 +722,19 @@ class InventoryItemViewSet(NautobotModelViewSet):
 
 
 class ConsoleConnectionViewSet(ListModelMixin, GenericViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = ConsolePort.objects.prefetch_related("device", "_path").filter(_path__destination_id__isnull=False)
+    queryset = ConsolePort.objects.select_related("device", "_path").filter(_path__destination_id__isnull=False)
     serializer_class = serializers.ConsolePortSerializer
     filterset_class = filters.ConsoleConnectionFilterSet
 
 
 class PowerConnectionViewSet(ListModelMixin, GenericViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = PowerPort.objects.prefetch_related("device", "_path").filter(_path__destination_id__isnull=False)
+    queryset = PowerPort.objects.select_related("device", "_path").filter(_path__destination_id__isnull=False)
     serializer_class = serializers.PowerPortSerializer
     filterset_class = filters.PowerConnectionFilterSet
 
 
 class InterfaceConnectionViewSet(ListModelMixin, GenericViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Interface.objects.prefetch_related("device", "_path").filter(
+    queryset = Interface.objects.select_related("device", "_path").filter(
         # Avoid duplicate connections by only selecting the lower PK in a connected pair
         _path__destination_id__isnull=False,
         pk__lt=F("_path__destination_id"),
@@ -766,8 +749,7 @@ class InterfaceConnectionViewSet(ListModelMixin, GenericViewSet):
 
 
 class CableViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Cable.objects.prefetch_related("status", "termination_a", "termination_b")
+    queryset = Cable.objects.select_related("status").prefetch_related("termination_a", "termination_b")
     serializer_class = serializers.CableSerializer
     filterset_class = filters.CableFilterSet
 
@@ -793,8 +775,7 @@ class VirtualChassisViewSet(NautobotModelViewSet):
 
 
 class PowerPanelViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = PowerPanel.objects.prefetch_related("site", "rack_group").annotate(
+    queryset = PowerPanel.objects.select_related("site", "rack_group").annotate(
         powerfeed_count=count_related(PowerFeed, "power_panel")
     )
     serializer_class = serializers.PowerPanelSerializer
@@ -807,16 +788,12 @@ class PowerPanelViewSet(NautobotModelViewSet):
 
 
 class PowerFeedViewSet(PathEndpointMixin, StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = PowerFeed.objects.prefetch_related(
+    queryset = PowerFeed.objects.select_related(
         "power_panel",
         "rack",
-        "_path__destination",
         "cable",
-        "_cable_peer",
         "status",
-        "tags",
-    )
+    ).prefetch_related("tags", "_cable_peer", "_path__destination")
     serializer_class = serializers.PowerFeedSerializer
     filterset_class = filters.PowerFeedFilterSet
 
