@@ -519,9 +519,6 @@ class BaseInterface(RelationshipModel, StatusModel):
         if not self.mode and self.untagged_vlan is not None:
             raise ValidationError({"untagged_vlan": "Mode must be set when specifying untagged_vlan"})
 
-        if self.tagged_vlans.exists() and self.mode != InterfaceModeChoices.MODE_TAGGED:
-            raise ValidationError({"tagged_vlans": f"Clear tagged_vlans to set mode to {self.mode}"})
-
     def save(self, *args, **kwargs):
 
         if not self.status:
@@ -630,7 +627,7 @@ class Interface(CableTermination, PathEndpoint, ComponentModel, BaseInterface):
             self.enabled,
             self.mac_address,
             self.mtu,
-            self.mgmt_only,
+            str(self.mgmt_only),
             self.description,
             self.get_mode_display(),
             self.get_status_display(),
@@ -1037,6 +1034,6 @@ class InventoryItem(MPTTModel, ComponentModel):
             self.part_id,
             self.serial,
             self.asset_tag,
-            self.discovered,
+            str(self.discovered),
             self.description,
         )
