@@ -1,6 +1,7 @@
 import logging
 
 from django.contrib.contenttypes.models import ContentType
+from django.core.exceptions import ValidationError as DjangoValidationError
 from django.db.models import Q
 from drf_spectacular.utils import extend_schema_field
 from rest_framework.exceptions import PermissionDenied
@@ -265,17 +266,35 @@ class RelationshipModelSerializerMixin(ValidatedModelSerializer):
     relationships = RelationshipsDataField(required=False, source="*")
 
     def create(self, validated_data):
-        relationships = validated_data.pop("relationships", {})
+        relationships_data = validated_data.pop("relationships", {})
+        required_relationships_errors = self.Meta().model.required_related_objects_errors(
+            output_for="api", initial_data=relationships_data
+        )
+        if required_relationships_errors:
+            raise ValidationError({"relationships": required_relationships_errors})
         instance = super().create(validated_data)
-        if relationships:
-            self._save_relationships(instance, relationships)
+        if relationships_data:
+            try:
+                self._save_relationships(instance, relationships_data)
+            except DjangoValidationError as error:
+                raise ValidationError(str(error))
         return instance
 
     def update(self, instance, validated_data):
-        relationships = validated_data.pop("relationships", {})
+        relationships_key_specified = "relationships" in self.context["request"].data
+        relationships_data = validated_data.pop("relationships", {})
+        required_relationships_errors = self.Meta().model.required_related_objects_errors(
+            output_for="api",
+            initial_data=relationships_data,
+            relationships_key_specified=relationships_key_specified,
+            instance=instance,
+        )
+        if required_relationships_errors:
+            raise ValidationError({"relationships": required_relationships_errors})
+
         instance = super().update(instance, validated_data)
-        if relationships:
-            self._save_relationships(instance, relationships)
+        if relationships_data:
+            self._save_relationships(instance, relationships_data)
         return instance
 
     def _save_relationships(self, instance, relationships):
