@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.core.exceptions import ObjectDoesNotExist
 from django.urls import NoReverseMatch
@@ -50,6 +51,7 @@ from nautobot.extras.models import (
     GraphQLQuery,
     ImageAttachment,
     Job,
+    JobButton,
     JobHook,
     JobLogEntry,
     JobResult,
@@ -112,6 +114,7 @@ from .nested_serializers import (  # noqa: F401
     NestedTagSerializer,
     NestedWebhookSerializer,
     NestedJobHookSerializer,
+    NestedJobButtonSerializer,
 )
 
 #
@@ -343,6 +346,20 @@ class ConfigContextSerializer(ValidatedModelSerializer, NotesSerializerMixin):
     )
     tags = serializers.SlugRelatedField(queryset=Tag.objects.all(), slug_field="slug", required=False, many=True)
 
+    dynamic_groups = SerializedPKRelatedField(
+        queryset=DynamicGroup.objects.all(),
+        serializer=NestedDynamicGroupSerializer,
+        required=False,
+        many=True,
+    )
+
+    # Conditional enablement of dynamic groups filtering
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+        if not settings.CONFIG_CONTEXT_DYNAMIC_GROUPS_ENABLED:
+            self.fields.pop("dynamic_groups")
+
     class Meta:
         model = ConfigContext
         fields = [
@@ -366,6 +383,7 @@ class ConfigContextSerializer(ValidatedModelSerializer, NotesSerializerMixin):
             "tenant_groups",
             "tenants",
             "tags",
+            "dynamic_groups",
             "data",
         ]
 
@@ -767,6 +785,7 @@ class JobSerializer(NautobotModelSerializer, TaggedModelSerializerMixin):
             "installed",
             "enabled",
             "is_job_hook_receiver",
+            "is_job_button_receiver",
             "has_sensitive_variables",
             "has_sensitive_variables_override",
             "approval_required",
@@ -1042,6 +1061,30 @@ class JobLogEntrySerializer(BaseModelSerializer):
         return obj.created.isoformat()
 
 
+#
+# Job Button
+#
+
+
+class JobButtonSerializer(ValidatedModelSerializer, NotesSerializerMixin):
+    url = serializers.HyperlinkedIdentityField(view_name="extras-api:jobbutton-detail")
+    content_types = ContentTypeField(queryset=ContentType.objects.all(), many=True)
+
+    class Meta:
+        model = JobButton
+        fields = (
+            "url",
+            "job",
+            "name",
+            "content_types",
+            "text",
+            "weight",
+            "group_name",
+            "button_class",
+            "confirmation",
+        )
+
+
 #
 # Notes
 #
