@@ -19,12 +19,19 @@ from django.utils import timezone
 
 from django_celery_beat.clockedschedule import clocked
 from django_celery_beat.managers import ExtendedManager
+from prometheus_client import Histogram
 
 from nautobot.core.celery import NautobotKombuJSONEncoder
 from nautobot.core.fields import AutoSlugField, slugify_dots_to_dashes
 from nautobot.core.models import BaseModel
 from nautobot.core.models.generics import OrganizationalModel, PrimaryModel
-from nautobot.extras.choices import JobExecutionType, JobResultStatusChoices, JobSourceChoices, LogLevelChoices
+from nautobot.extras.choices import (
+    ButtonClassChoices,
+    JobExecutionType,
+    JobResultStatusChoices,
+    JobSourceChoices,
+    LogLevelChoices,
+)
 from nautobot.extras.constants import (
     JOB_LOG_MAX_ABSOLUTE_URL_LENGTH,
     JOB_LOG_MAX_GROUPING_LENGTH,
@@ -35,6 +42,8 @@ from nautobot.extras.constants import (
     JOB_MAX_SOURCE_LENGTH,
     JOB_OVERRIDABLE_FIELDS,
 )
+from nautobot.extras.models import ChangeLoggedModel
+from nautobot.extras.models.mixins import NotesMixin
 from nautobot.extras.plugins.utils import import_object
 from nautobot.extras.querysets import JobQuerySet, ScheduledJobExtendedQuerySet
 from nautobot.extras.utils import (
@@ -44,6 +53,7 @@ from nautobot.extras.utils import (
     get_job_content_type,
     jobs_in_directory,
 )
+from nautobot.utilities.fields import JSONArrayField
 from nautobot.utilities.logging import sanitize
 
 from .customfields import CustomFieldModel
@@ -59,6 +69,14 @@ logger = logging.getLogger(__name__)
 # objects being created within transaction.atomic().
 JOB_LOGS = "job_logs"
 
+# The JOB_RESULT_METRIC variable is a counter metric that counts executions of jobs,
+# including information beyond what a tool like flower could get by introspecting
+# the celery task queue. This is accomplished by looking one abstraction deeper into
+# the job model of Nautobot.
+JOB_RESULT_METRIC = Histogram(
+    "nautobot_job_duration_seconds", "Results of Nautobot jobs.", ["grouping", "name", "status"]
+)
+
 
 @extras_features(
     "custom_fields",
@@ -137,6 +155,10 @@ class Job(PrimaryModel):
         default=False, editable=False, help_text="Whether this job is a job hook receiver"
     )
 
+    is_job_button_receiver = models.BooleanField(
+        default=False, editable=False, help_text="Whether this job is a job button receiver"
+    )
+
     has_sensitive_variables = models.BooleanField(
         default=True, help_text="Whether this job contains sensitive variables"
     )
@@ -170,6 +192,12 @@ class Job(PrimaryModel):
         help_text="Maximum runtime in seconds before the job will be forcibly terminated."
         "<br>Set to 0 to use Nautobot system default",
     )
+    task_queues = JSONArrayField(
+        base_field=models.CharField(max_length=100, blank=True),
+        default=list,
+        blank=True,
+        help_text="Comma separated list of task queues that this job can run on. A blank list will use the default queue",
+    )
 
     # Flags to indicate whether the above properties are inherited from the source code or overridden by the database
     grouping_override = models.BooleanField(
@@ -213,6 +241,10 @@ class Job(PrimaryModel):
         default=False,
         help_text="If set, the configured value will remain even if the underlying Job source code changes",
     )
+    task_queues_override = models.BooleanField(
+        default=False,
+        help_text="If set, the configured value will remain even if the underlying Job source code changes",
+    )
 
     objects = JobQuerySet.as_manager()
 
@@ -475,6 +507,8 @@ class JobLogEntry(BaseModel):
     log_object = models.CharField(max_length=JOB_LOG_MAX_LOG_OBJECT_LENGTH, null=True, blank=True)
     absolute_url = models.CharField(max_length=JOB_LOG_MAX_ABSOLUTE_URL_LENGTH, null=True, blank=True)
 
+    csv_headers = ["created", "grouping", "log_level", "log_object", "message"]
+
     def __str__(self):
         return self.message
 
@@ -483,6 +517,10 @@ class JobLogEntry(BaseModel):
         get_latest_by = "created"
         verbose_name_plural = "job log entries"
 
+    def to_csv(self):
+        """Indicates model fields to return as csv."""
+        return (str(self.created), self.grouping, self.log_level, self.log_object, self.message)
+
 
 #
 # Job results
@@ -652,7 +690,14 @@ class JobResult(BaseModel, CustomFieldModel):
         """
         self.status = status
         if status in JobResultStatusChoices.TERMINAL_STATE_CHOICES:
+            # Only add metrics if we have a related job model. If we are moving to a terminal state we should always
+            # have a related job model, so this shouldn't be too tight of a restriction.
             self.completed = timezone.now()
+            if self.job_model:
+                duration = self.completed - self.created
+                JOB_RESULT_METRIC.labels(self.job_model.grouping, self.job_model.name, status).observe(
+                    duration.total_seconds()
+                )
 
     @classmethod
     def enqueue_job(cls, func, name, obj_type, user, *args, celery_kwargs=None, schedule=None, **kwargs):
@@ -774,6 +819,61 @@ class JobResult(BaseModel, CustomFieldModel):
             logger.log(log_level, message)
 
 
+#
+# Job Button
+#
+
+
+@extras_features("graphql")
+class JobButton(BaseModel, ChangeLoggedModel, NotesMixin):
+    """
+    A predefined button that includes all necessary information to run a Nautobot Job based on a single object as a source.
+    The button text field accepts Jinja2 template code to be rendered with an object as context.
+    """
+
+    content_types = models.ManyToManyField(
+        to=ContentType,
+        related_name="job_buttons",
+        verbose_name="Object types",
+        help_text="The object type(s) to which this job button applies.",
+    )
+    name = models.CharField(max_length=100, unique=True)
+    text = models.CharField(
+        max_length=500,
+        help_text="Jinja2 template code for button text. Reference the object as <code>{{ obj }}</code> such as <code>{{ obj.platform.slug }}</code>. Buttons which render as empty text will not be displayed.",
+    )
+    job = models.ForeignKey(
+        to="extras.Job",
+        on_delete=models.CASCADE,
+        help_text="Job this button will run",
+        limit_choices_to={"is_job_button_receiver": True},
+    )
+    weight = models.PositiveSmallIntegerField(default=100)
+    group_name = models.CharField(
+        max_length=50,
+        blank=True,
+        help_text="Buttons with the same group will appear as a dropdown menu. Group dropdown buttons will inherit the button class from the button with the lowest weight in the group.",
+    )
+    button_class = models.CharField(
+        max_length=30,
+        choices=ButtonClassChoices,
+        default=ButtonClassChoices.CLASS_DEFAULT,
+    )
+    confirmation = models.BooleanField(
+        help_text="Enable confirmation pop-up box. <span class='text-danger'>WARNING: unselecting this option will allow the Job to run (and commit changes) with a single click!</span>",
+        default=True,
+    )
+
+    class Meta:
+        ordering = ["group_name", "weight", "name"]
+
+    def __str__(self):
+        return self.name
+
+    def get_absolute_url(self):
+        return reverse("extras:jobbutton", kwargs={"pk": self.pk})
+
+
 class ScheduledJobs(models.Model):
     """Helper table for tracking updates to scheduled tasks.
     This stores a single row with ident=1.  last_update is updated
@@ -788,14 +888,18 @@ class ScheduledJobs(models.Model):
     objects = ExtendedManager()
 
     @classmethod
-    def changed(cls, instance, **kwargs):
+    def changed(cls, instance, raw=False, **kwargs):
         """This function acts as a signal handler to track changes to the scheduled job that is triggered before a change"""
+        if raw:
+            return
         if not instance.no_changes:
             cls.update_changed()
 
     @classmethod
-    def update_changed(cls, **kwargs):
+    def update_changed(cls, raw=False, **kwargs):
         """This function acts as a signal handler to track changes to the scheduled job that is triggered after a change"""
+        if raw:
+            return
         cls.objects.update_or_create(ident=1, defaults={"last_update": timezone.now()})
 
     @classmethod
@@ -1004,7 +1108,7 @@ class ScheduledJob(BaseModel):
         elif self.interval == JobExecutionType.TYPE_DAILY:
             return schedules.crontab(minute=t.minute, hour=t.hour)
         elif self.interval == JobExecutionType.TYPE_WEEKLY:
-            return schedules.crontab(minute=t.minute, hour=t.hour, day_of_week=t.weekday())
+            return schedules.crontab(minute=t.minute, hour=t.hour, day_of_week=t.strftime("%w"))
         elif self.interval == JobExecutionType.TYPE_CUSTOM:
             return self.get_crontab(self.crontab)
         raise ValueError(f"I do not know to convert {self.interval} to a Cronjob!")
