@@ -26,7 +26,7 @@ from nautobot.core.fields import AutoSlugField
 from nautobot.core.models import BaseModel
 from nautobot.core.models.generics import OrganizationalModel
 from nautobot.extras.choices import (
-    CustomLinkButtonClassChoices,
+    ButtonClassChoices,
     WebhookHttpMethodChoices,
 )
 from nautobot.extras.constants import HTTP_CONTENT_TYPE_JSON
@@ -63,6 +63,12 @@ class ConfigContextSchemaValidationMixin:
                 raise ValidationError({data_field: [f"Validation using the JSON Schema {schema} failed.", e.message]})
 
 
+def limit_dynamic_group_choices():
+    return models.Q(content_type__app_label="virtualization", content_type__model="virtualmachine") | models.Q(
+        content_type__app_label="dcim", content_type__model="device"
+    )
+
+
 @extras_features("graphql")
 class ConfigContext(BaseModel, ChangeLoggedModel, ConfigContextSchemaValidationMixin, NotesMixin):
     """
@@ -112,6 +118,11 @@ class ConfigContext(BaseModel, ChangeLoggedModel, ConfigContextSchemaValidationM
     tenant_groups = models.ManyToManyField(to="tenancy.TenantGroup", related_name="+", blank=True)
     tenants = models.ManyToManyField(to="tenancy.Tenant", related_name="+", blank=True)
     tags = models.ManyToManyField(to="extras.Tag", related_name="+", blank=True)
+
+    # Due to feature flag CONFIG_CONTEXT_DYNAMIC_GROUPS_ENABLED this field will remain empty unless set to True.
+    dynamic_groups = models.ManyToManyField(
+        to="extras.DynamicGroup", related_name="+", blank=True, limit_choices_to=limit_dynamic_group_choices
+    )
     data = models.JSONField(encoder=DjangoJSONEncoder)
 
     objects = ConfigContextQuerySet.as_manager()
@@ -331,8 +342,8 @@ class CustomLink(BaseModel, ChangeLoggedModel, NotesMixin):
     )
     button_class = models.CharField(
         max_length=30,
-        choices=CustomLinkButtonClassChoices,
-        default=CustomLinkButtonClassChoices.CLASS_DEFAULT,
+        choices=ButtonClassChoices,
+        default=ButtonClassChoices.CLASS_DEFAULT,
         help_text="The class of the first link in a group will be used for the dropdown button",
     )
     new_window = models.BooleanField(help_text="Force link to open in a new window")
