@@ -46,9 +46,8 @@ class IPAMRootView(APIRootView):
 
 
 class VRFViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
     queryset = (
-        VRF.objects.prefetch_related("tenant")
+        VRF.objects.select_related("tenant")
         .prefetch_related("import_targets", "export_targets", "tags")
         .annotate(
             ipaddress_count=count_related(IPAddress, "vrf"),
@@ -65,8 +64,7 @@ class VRFViewSet(NautobotModelViewSet):
 
 
 class RouteTargetViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = RouteTarget.objects.prefetch_related("tenant").prefetch_related("tags")
+    queryset = RouteTarget.objects.select_related("tenant").prefetch_related("tags")
     serializer_class = serializers.RouteTargetSerializer
     filterset_class = filters.RouteTargetFilterSet
 
@@ -88,8 +86,7 @@ class RIRViewSet(NautobotModelViewSet):
 
 
 class AggregateViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = Aggregate.objects.prefetch_related("rir").prefetch_related("tags")
+    queryset = Aggregate.objects.select_related("rir").prefetch_related("tags")
     serializer_class = serializers.AggregateSerializer
     filterset_class = filters.AggregateFilterSet
 
@@ -114,16 +111,14 @@ class RoleViewSet(NautobotModelViewSet):
 
 
 class PrefixViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tgs: m2m)
-    queryset = Prefix.objects.prefetch_related(
+    queryset = Prefix.objects.select_related(
         "role",
         "site",
         "status",
-        "tags",
         "tenant",
         "vlan",
         "vrf__tenant",
-    )
+    ).prefetch_related("tags")
     serializer_class = serializers.PrefixSerializer
     filterset_class = filters.PrefixFilterSet
 
@@ -313,16 +308,12 @@ class PrefixViewSet(StatusViewSetMixin, NautobotModelViewSet):
     update=extend_schema(responses={"200": serializers.IPAddressSerializerLegacy}, versions=["1.2"]),
 )
 class IPAddressViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = IPAddress.objects.prefetch_related(
-        "assigned_object",
+    queryset = IPAddress.objects.select_related(
         "nat_inside",
-        "nat_outside_list",
         "status",
-        "tags",
         "tenant",
         "vrf__tenant",
-    )
+    ).prefetch_related("tags", "assigned_object", "nat_outside_list")
     serializer_class = serializers.IPAddressSerializer
     filterset_class = filters.IPAddressFilterSet
 
@@ -364,8 +355,7 @@ class IPAddressViewSet(StatusViewSetMixin, NautobotModelViewSet):
 
 
 class VLANGroupViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VLANGroup.objects.prefetch_related("site").annotate(vlan_count=count_related(VLAN, "group"))
+    queryset = VLANGroup.objects.select_related("site").annotate(vlan_count=count_related(VLAN, "group"))
     serializer_class = serializers.VLANGroupSerializer
     filterset_class = filters.VLANGroupFilterSet
 
@@ -376,15 +366,17 @@ class VLANGroupViewSet(NautobotModelViewSet):
 
 
 class VLANViewSet(StatusViewSetMixin, NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = VLAN.objects.prefetch_related(
-        "group",
-        "site",
-        "status",
-        "role",
-        "tags",
-        "tenant",
-    ).annotate(prefix_count=count_related(Prefix, "vlan"))
+    queryset = (
+        VLAN.objects.select_related(
+            "group",
+            "site",
+            "status",
+            "role",
+            "tenant",
+        )
+        .prefetch_related("tags")
+        .annotate(prefix_count=count_related(Prefix, "vlan"))
+    )
     serializer_class = serializers.VLANSerializer
     filterset_class = filters.VLANFilterSet
 
@@ -395,7 +387,6 @@ class VLANViewSet(StatusViewSetMixin, NautobotModelViewSet):
 
 
 class ServiceViewSet(NautobotModelViewSet):
-    # v2 TODO(jathan): Replace prefetch_related with select_related (except tags: m2m)
-    queryset = Service.objects.prefetch_related("device", "virtual_machine", "tags", "ipaddresses")
+    queryset = Service.objects.select_related("device", "virtual_machine").prefetch_related("tags", "ipaddresses")
     serializer_class = serializers.ServiceSerializer
     filterset_class = filters.ServiceFilterSet
