@@ -48,13 +48,11 @@ class VRFView(generic.ObjectView):
     def get_extra_context(self, request, instance):
         prefix_count = Prefix.objects.restrict(request.user, "view").filter(vrf=instance).count()
 
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         import_targets_table = tables.RouteTargetTable(
-            instance.import_targets.prefetch_related("tenant"), orderable=False
+            instance.import_targets.select_related("tenant"), orderable=False
         )
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         export_targets_table = tables.RouteTargetTable(
-            instance.export_targets.prefetch_related("tenant"), orderable=False
+            instance.export_targets.select_related("tenant"), orderable=False
         )
 
         return {
@@ -81,16 +79,14 @@ class VRFBulkImportView(generic.BulkImportView):
 
 
 class VRFBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VRF.objects.prefetch_related("tenant")
+    queryset = VRF.objects.select_related("tenant")
     filterset = filters.VRFFilterSet
     table = tables.VRFTable
     form = forms.VRFBulkEditForm
 
 
 class VRFBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VRF.objects.prefetch_related("tenant")
+    queryset = VRF.objects.select_related("tenant")
     filterset = filters.VRFFilterSet
     table = tables.VRFTable
 
@@ -111,9 +107,8 @@ class RouteTargetView(generic.ObjectView):
     queryset = RouteTarget.objects.all()
 
     def get_extra_context(self, request, instance):
-        # v2 TODO(jathan): Replace prefetch_related with select_related
-        importing_vrfs_table = tables.VRFTable(instance.importing_vrfs.prefetch_related("tenant"), orderable=False)
-        exporting_vrfs_table = tables.VRFTable(instance.exporting_vrfs.prefetch_related("tenant"), orderable=False)
+        importing_vrfs_table = tables.VRFTable(instance.importing_vrfs.select_related("tenant"), orderable=False)
+        exporting_vrfs_table = tables.VRFTable(instance.exporting_vrfs.select_related("tenant"), orderable=False)
 
         return {
             "importing_vrfs_table": importing_vrfs_table,
@@ -137,16 +132,14 @@ class RouteTargetBulkImportView(generic.BulkImportView):
 
 
 class RouteTargetBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = RouteTarget.objects.prefetch_related("tenant")
+    queryset = RouteTarget.objects.select_related("tenant")
     filterset = filters.RouteTargetFilterSet
     table = tables.RouteTargetTable
     form = forms.RouteTargetBulkEditForm
 
 
 class RouteTargetBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = RouteTarget.objects.prefetch_related("tenant")
+    queryset = RouteTarget.objects.select_related("tenant")
     filterset = filters.RouteTargetFilterSet
     table = tables.RouteTargetTable
 
@@ -169,8 +162,7 @@ class RIRView(generic.ObjectView):
     def get_extra_context(self, request, instance):
 
         # Aggregates
-        # v2 TODO(jathan): Replace prefetch_related with select_related
-        aggregates = Aggregate.objects.restrict(request.user, "view").filter(rir=instance).prefetch_related("tenant")
+        aggregates = Aggregate.objects.restrict(request.user, "view").filter(rir=instance).select_related("tenant")
 
         aggregate_table = tables.AggregateTable(aggregates)
 
@@ -248,11 +240,10 @@ class AggregateView(generic.ObjectView):
 
     def get_extra_context(self, request, instance):
         # Find all child prefixes contained by this aggregate
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         child_prefixes = (
             Prefix.objects.restrict(request.user, "view")
             .net_contained_or_equal(instance.prefix)
-            .prefetch_related("site", "role")
+            .select_related("site", "role")
             .order_by("network")
             .annotate_tree()
         )
@@ -302,16 +293,14 @@ class AggregateBulkImportView(generic.BulkImportView):
 
 
 class AggregateBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Aggregate.objects.prefetch_related("rir")
+    queryset = Aggregate.objects.select_related("rir")
     filterset = filters.AggregateFilterSet
     table = tables.AggregateTable
     form = forms.AggregateBulkEditForm
 
 
 class AggregateBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Aggregate.objects.prefetch_related("rir")
+    queryset = Aggregate.objects.select_related("rir")
     filterset = filters.AggregateFilterSet
     table = tables.AggregateTable
 
@@ -336,11 +325,10 @@ class RoleView(generic.ObjectView):
     def get_extra_context(self, request, instance):
 
         # Prefixes
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         prefixes = (
             Prefix.objects.restrict(request.user, "view")
             .filter(role=instance)
-            .prefetch_related(
+            .select_related(
                 "site",
                 "status",
                 "tenant",
@@ -359,11 +347,10 @@ class RoleView(generic.ObjectView):
         RequestConfig(request, paginate).configure(prefix_table)
 
         # VLANs
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         vlans = (
             VLAN.objects.restrict(request.user, "view")
             .filter(role=instance)
-            .prefetch_related(
+            .select_related(
                 "group",
                 "site",
                 "status",
@@ -453,8 +440,7 @@ class PrefixListView(generic.ObjectListView):
 
 
 class PrefixView(generic.ObjectView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Prefix.objects.prefetch_related(
+    queryset = Prefix.objects.select_related(
         "role",
         "site__region",
         "status",
@@ -470,25 +456,23 @@ class PrefixView(generic.ObjectView):
             aggregate = None
 
         # Parent prefixes table
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         parent_prefixes = (
             Prefix.objects.restrict(request.user, "view")
             .net_contains(instance.prefix)
             .filter(Q(vrf=instance.vrf) | Q(vrf__isnull=True))
-            .prefetch_related("role", "site", "status")
+            .select_related("role", "site", "status")
             .annotate_tree()
         )
         parent_prefix_table = tables.PrefixTable(list(parent_prefixes), orderable=False)
         parent_prefix_table.exclude = ("vrf",)
 
         # Duplicate prefixes table
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         duplicate_prefixes = (
             Prefix.objects.restrict(request.user, "view")
             .net_equals(instance.prefix)
             .filter(vrf=instance.vrf)
             .exclude(pk=instance.pk)
-            .prefetch_related("role", "site", "status")
+            .select_related("role", "site", "status")
         )
         duplicate_prefix_table = tables.PrefixTable(list(duplicate_prefixes), orderable=False)
         duplicate_prefix_table.exclude = ("vrf",)
@@ -506,11 +490,10 @@ class PrefixPrefixesView(generic.ObjectView):
 
     def get_extra_context(self, request, instance):
         # Child prefixes table
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         child_prefixes = (
             instance.get_child_prefixes()
             .restrict(request.user, "view")
-            .prefetch_related("site", "status", "role", "vlan")
+            .select_related("site", "status", "role", "vlan")
             .annotate_tree()
         )
 
@@ -553,11 +536,11 @@ class PrefixIPAddressesView(generic.ObjectView):
 
     def get_extra_context(self, request, instance):
         # Find all IPAddresses belonging to this Prefix
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         ipaddresses = (
             instance.get_child_ips()
             .restrict(request.user, "view")
-            .prefetch_related("vrf", "primary_ip4_for", "primary_ip6_for", "status")
+            .select_related("vrf", "status")
+            .prefetch_related("primary_ip4_for", "primary_ip6_for")
         )
 
         # Add available IP addresses to the table if requested
@@ -611,16 +594,14 @@ class PrefixBulkImportView(generic.BulkImportView):
 
 
 class PrefixBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Prefix.objects.prefetch_related("site", "status", "vrf__tenant", "tenant", "vlan", "role")
+    queryset = Prefix.objects.select_related("site", "status", "vrf__tenant", "tenant", "vlan", "role")
     filterset = filters.PrefixFilterSet
     table = tables.PrefixTable
     form = forms.PrefixBulkEditForm
 
 
 class PrefixBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Prefix.objects.prefetch_related("site", "status", "vrf__tenant", "tenant", "vlan", "role")
+    queryset = Prefix.objects.select_related("site", "status", "vrf__tenant", "tenant", "vlan", "role")
     filterset = filters.PrefixFilterSet
     table = tables.PrefixTable
 
@@ -638,28 +619,25 @@ class IPAddressListView(generic.ObjectListView):
 
 
 class IPAddressView(generic.ObjectView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = IPAddress.objects.prefetch_related("vrf__tenant", "tenant")
+    queryset = IPAddress.objects.select_related("vrf__tenant", "tenant")
 
     def get_extra_context(self, request, instance):
         # Parent prefixes table
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         parent_prefixes = (
             Prefix.objects.restrict(request.user, "view")
             .net_contains_or_equals(instance.address)
             .filter(vrf=instance.vrf)
-            .prefetch_related("site", "status", "role")
+            .select_related("site", "status", "role")
         )
         parent_prefixes_table = tables.PrefixTable(list(parent_prefixes), orderable=False)
         parent_prefixes_table.exclude = ("vrf",)
 
         # Duplicate IPs table
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         duplicate_ips = (
             IPAddress.objects.restrict(request.user, "view")
             .filter(vrf=instance.vrf, host=instance.host)
             .exclude(pk=instance.pk)
-            .prefetch_related("nat_inside")
+            .select_related("nat_inside")
         )
         # Exclude anycast IPs if this IP is anycast
         if instance.role == IPAddressRoleChoices.ROLE_ANYCAST:
@@ -746,8 +724,7 @@ class IPAddressAssignView(generic.ObjectView):
 
         if form.is_valid():
 
-            # v2 TODO(jathan): Replace prefetch_related with select_related
-            addresses = self.queryset.prefetch_related("vrf", "tenant")
+            addresses = self.queryset.select_related("vrf", "tenant")
             # Limit to 100 results
             addresses = filters.IPAddressFilterSet(request.POST, addresses).qs[:100]
             table = tables.IPAddressAssignTable(addresses)
@@ -782,16 +759,14 @@ class IPAddressBulkImportView(generic.BulkImportView):
 
 
 class IPAddressBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = IPAddress.objects.prefetch_related("status", "tenant", "vrf__tenant")
+    queryset = IPAddress.objects.select_related("status", "tenant", "vrf__tenant")
     filterset = filters.IPAddressFilterSet
     table = tables.IPAddressTable
     form = forms.IPAddressBulkEditForm
 
 
 class IPAddressBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = IPAddress.objects.prefetch_related("status", "tenant", "vrf__tenant")
+    queryset = IPAddress.objects.select_related("status", "tenant", "vrf__tenant")
     filterset = filters.IPAddressFilterSet
     table = tables.IPAddressTable
 
@@ -802,8 +777,7 @@ class IPAddressBulkDeleteView(generic.BulkDeleteView):
 
 
 class VLANGroupListView(generic.ObjectListView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VLANGroup.objects.prefetch_related("site").annotate(vlan_count=count_related(VLAN, "group"))
+    queryset = VLANGroup.objects.select_related("site").annotate(vlan_count=count_related(VLAN, "group"))
     filterset = filters.VLANGroupFilterSet
     filterset_form = forms.VLANGroupFilterForm
     table = tables.VLANGroupTable
@@ -865,8 +839,7 @@ class VLANGroupBulkImportView(generic.BulkImportView):
 
 
 class VLANGroupBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VLANGroup.objects.prefetch_related("site").annotate(vlan_count=count_related(VLAN, "group"))
+    queryset = VLANGroup.objects.select_related("site").annotate(vlan_count=count_related(VLAN, "group"))
     filterset = filters.VLANGroupFilterSet
     table = tables.VLANGroupTable
 
@@ -884,8 +857,7 @@ class VLANListView(generic.ObjectListView):
 
 
 class VLANView(generic.ObjectView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VLAN.objects.prefetch_related(
+    queryset = VLAN.objects.select_related(
         "role",
         "site__region",
         "status",
@@ -893,11 +865,10 @@ class VLANView(generic.ObjectView):
     )
 
     def get_extra_context(self, request, instance):
-        # v2 TODO(jathan): Replace prefetch_related with select_related
         prefixes = (
             Prefix.objects.restrict(request.user, "view")
             .filter(vlan=instance)
-            .prefetch_related(
+            .select_related(
                 "site",
                 "status",
                 "role",
@@ -917,8 +888,7 @@ class VLANInterfacesView(generic.ObjectView):
     template_name = "ipam/vlan_interfaces.html"
 
     def get_extra_context(self, request, instance):
-        # v2 TODO(jathan): Replace prefetch_related with select_related
-        interfaces = instance.get_interfaces().prefetch_related("device")
+        interfaces = instance.get_interfaces().select_related("device")
         members_table = tables.VLANDevicesTable(interfaces)
 
         paginate = {
@@ -938,8 +908,7 @@ class VLANVMInterfacesView(generic.ObjectView):
     template_name = "ipam/vlan_vminterfaces.html"
 
     def get_extra_context(self, request, instance):
-        # v2 TODO(jathan): Replace prefetch_related with select_related
-        interfaces = instance.get_vminterfaces().prefetch_related("virtual_machine")
+        interfaces = instance.get_vminterfaces().select_related("virtual_machine")
         members_table = tables.VLANVirtualMachinesTable(interfaces)
 
         paginate = {
@@ -971,8 +940,7 @@ class VLANBulkImportView(generic.BulkImportView):
 
 
 class VLANBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VLAN.objects.prefetch_related(
+    queryset = VLAN.objects.select_related(
         "group",
         "site",
         "status",
@@ -985,8 +953,7 @@ class VLANBulkEditView(generic.BulkEditView):
 
 
 class VLANBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = VLAN.objects.prefetch_related(
+    queryset = VLAN.objects.select_related(
         "group",
         "site",
         "status",
@@ -1041,15 +1008,13 @@ class ServiceDeleteView(generic.ObjectDeleteView):
 
 
 class ServiceBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Service.objects.prefetch_related("device", "virtual_machine")
+    queryset = Service.objects.select_related("device", "virtual_machine")
     filterset = filters.ServiceFilterSet
     table = tables.ServiceTable
     form = forms.ServiceBulkEditForm
 
 
 class ServiceBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Service.objects.prefetch_related("device", "virtual_machine")
+    queryset = Service.objects.select_related("device", "virtual_machine")
     filterset = filters.ServiceFilterSet
     table = tables.ServiceTable
