@@ -82,8 +82,7 @@ class TenantListView(generic.ObjectListView):
 
 
 class TenantView(generic.ObjectView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Tenant.objects.prefetch_related("group")
+    queryset = Tenant.objects.select_related("group")
 
     def get_extra_context(self, request, instance):
         stats = {
@@ -126,15 +125,13 @@ class TenantBulkImportView(generic.BulkImportView):
 
 
 class TenantBulkEditView(generic.BulkEditView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Tenant.objects.prefetch_related("group")
+    queryset = Tenant.objects.select_related("group")
     filterset = filters.TenantFilterSet
     table = tables.TenantTable
     form = forms.TenantBulkEditForm
 
 
 class TenantBulkDeleteView(generic.BulkDeleteView):
-    # v2 TODO(jathan): Replace prefetch_related with select_related
-    queryset = Tenant.objects.prefetch_related("group")
+    queryset = Tenant.objects.select_related("group")
     filterset = filters.TenantFilterSet
     table = tables.TenantTable
