@@ -1,3 +1,6 @@
+import csv
+import re
+from io import StringIO
 from tree_queries.models import TreeNode
 from typing import Optional, Sequence
 from unittest import skipIf
@@ -17,7 +20,7 @@ from nautobot.extras.models import ChangeLoggedModel, CustomField, Relationship
 from nautobot.users.models import ObjectPermission
 from nautobot.utilities.templatetags.helpers import bettertitle, validated_viewname
 from nautobot.utilities.testing.mixins import NautobotTestCaseMixin
-from nautobot.utilities.utils import get_changes_for_model, get_filterset_for_model
+from nautobot.utilities.utils import get_changes_for_model, get_filterset_for_model, csv_format
 from .utils import disable_warnings, extract_page_body, get_deletable_objects, post_data
 
 
@@ -652,11 +655,8 @@ class ViewTestCases:
             content = extract_page_body(response.content.decode(response.charset))
             # TODO: it'd make test failures more readable if we strip the page headers/footers from the content
             if hasattr(self.model, "name"):
-                # TODO: https://github.com/nautobot/nautobot/issues/2580
-                #       This is fragile as we move toward more autogenerated test fixtures,
-                #       as "instance.name" may appear coincidentally in other page text if we're not careful.
-                self.assertIn(instance1.name, content, msg=content)
-                self.assertNotIn(instance2.name, content, msg=content)
+                self.assertRegex(content, r">\s*" + re.escape(instance1.name) + r"\s*<", msg=content)
+                self.assertNotRegex(content, r">\s*" + re.escape(instance2.name) + r"\s*<", msg=content)
             try:
                 self.assertIn(self._get_url("view", instance=instance1), content, msg=content)
                 self.assertNotIn(self._get_url("view", instance=instance2), content, msg=content)
@@ -744,12 +744,6 @@ class ViewTestCases:
                 response_body,
             )
 
-            # Built-in CSV export
-            if hasattr(self.model, "csv_headers"):
-                response = self.client.get(f"{self._get_url('list')}?export")
-                self.assertHttpStatus(response, 200)
-                self.assertEqual(response.get("Content-Type"), "text/csv")
-
         @override_settings(EXEMPT_VIEW_PERMISSIONS=[])
         def test_list_objects_with_constrained_permission(self):
             instance1, instance2 = self._get_queryset().all()[:2]
@@ -801,6 +795,39 @@ class ViewTestCases:
                 f"<div>You are viewing a table of {self.model._meta.verbose_name_plural}</div>", response_body
             )
 
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
+        def test_queryset_to_csv(self):
+            # Built-in CSV export
+            if not hasattr(self.model, "csv_headers"):
+                self.skipTest(f"{self.model} has no csv_headers attribute?")
+            response = self.client.get(f"{self._get_url('list')}?export")
+            self.assertHttpStatus(response, 200)
+            self.assertEqual(response.get("Content-Type"), "text/csv")
+            instance1 = self._get_queryset().first()
+            # With filtering
+            response = self.client.get(f"{self._get_url('list')}?export&id={instance1.pk}")
+            self.assertHttpStatus(response, 200)
+            self.assertEqual(response.get("Content-Type"), "text/csv")
+            response_body = response.content.decode(response.charset)
+            reader = csv.DictReader(StringIO(response_body))
+            # This line will make data a dictionary with csv headers as keys and corresponding csv values as values.
+            # For example:
+            # {'name': 'AFRINIC', 'slug': 'afrinic', 'is_private': '', 'description': ...'}
+            data = [dict(row) for row in reader][0]
+
+            # Get expected data
+            instance1_unformatted_data = [
+                *instance1.to_csv(),
+                *instance1.get_custom_fields().values(),
+            ]
+            # Format expected data using `csv_format`, parse back with `csv` and get first row
+            instance1_csv_data = next(iter(csv.reader([csv_format(instance1_unformatted_data)])))
+
+            instance1_cf_headers = ["cf_" + str(cf.slug) for cf in instance1.get_custom_fields().keys()]
+            instance1_csv_headers = list(self.model.csv_headers) + instance1_cf_headers
+            self.assertEqual(instance1_csv_headers, list(data.keys()))
+            self.assertEqual(instance1_csv_data, list(data.values()))
+
     class CreateMultipleObjectsViewTestCase(ModelViewTestCase):
         """
         Create multiple instances using a single form. Expects the creation of three new instances by default.
@@ -1061,42 +1088,52 @@ class ViewTestCases:
 
         @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
         def test_bulk_edit_objects_with_constrained_permission(self):
-            pk_list = list(self._get_queryset().values_list("pk", flat=True)[:3])
-            data = {
-                "pk": pk_list,
-                "_apply": True,  # Form button
-            }
-
-            # Append the form data to the request
-            data.update(post_data(self.bulk_edit_data))
-
-            # Dynamically determine a constraint that will *not* be matched by the updated objects.
+            # Select some objects that are *not* already set to match the first value in self.bulk_edit_data or null.
+            # We have to exclude null cases because Django filter()/exclude() doesn't like `__in=[None]` as a case.
             attr_name = list(self.bulk_edit_data.keys())[0]
-            field = self.model._meta.get_field(attr_name)
-            value = field.value_from_object(
-                self._get_queryset().exclude(**{attr_name: self.bulk_edit_data[attr_name]}).first()
-            )
+            objects = (
+                self._get_queryset()
+                .exclude(**{attr_name: self.bulk_edit_data[attr_name]})
+                .exclude(**{f"{attr_name}__isnull": True})
+            )[:3]
+            self.assertEqual(objects.count(), 3)
+            pk_list = list(objects.values_list("pk", flat=True))
 
-            # Assign constrained permission
+            # Define a permission that permits the above objects, but will not permit them after updating them.
+            field = self.model._meta.get_field(attr_name)
+            values = [field.value_from_object(obj) for obj in objects]
             obj_perm = ObjectPermission(
                 name="Test permission",
-                constraints={attr_name: value},
+                constraints={f"{attr_name}__in": values},
                 actions=["change"],
             )
             obj_perm.save()
             obj_perm.users.add(self.user)
             obj_perm.object_types.add(ContentType.objects.get_for_model(self.model))
 
+            # Build form data
+            data = {
+                "pk": pk_list,
+                "_apply": True,  # Form button
+            }
+            data.update(post_data(self.bulk_edit_data))
+
             # Attempt to bulk edit permitted objects into a non-permitted state
             response = self.client.post(self._get_url("bulk_edit"), data)
+            # 200 because we're sent back to the edit form to try again; if the update were successful it'd be a 302
             self.assertHttpStatus(response, 200)
+            # Assert that the objects are NOT updated
+            for instance in self._get_queryset().filter(pk__in=pk_list):
+                self.assertIn(field.value_from_object(instance), values)
+                self.assertNotEqual(field.value_from_object(instance), self.bulk_edit_data[attr_name])
 
-            # Update permission constraints
+            # Update permission constraints to permit all objects
             obj_perm.constraints = {"pk__gt": 0}
             obj_perm.save()
 
-            # Bulk edit permitted objects
+            # Bulk edit permitted objects and expect a redirect back to the list view
             self.assertHttpStatus(self.client.post(self._get_url("bulk_edit"), data), 302)
+            # Assert that the objects were all updated correctly
             for instance in self._get_queryset().filter(pk__in=pk_list):
                 self.assertInstanceEqual(instance, self.bulk_edit_data)
 
@@ -1404,3 +1441,39 @@ class ViewTestCases:
                 except AssertionError:
                     pass
             self.assertEqual(matching_count, self.bulk_create_count)
+
+        @override_settings(EXEMPT_VIEW_PERMISSIONS=["*"])
+        def test_bulk_rename(self):
+            obj_perm = ObjectPermission(name="Test permission", actions=["change"])
+            obj_perm.save()
+            obj_perm.users.add(self.user)
+            obj_perm.object_types.add(ContentType.objects.get_for_model(self.model))
+
+            objects = self.selected_objects
+            pk_list = [obj.pk for obj in objects]
+            # Apply button not yet clicked
+            data = {"pk": pk_list}
+            data.update(self.rename_data)
+            verbose_name_plural = self.model._meta.verbose_name_plural
+
+            with self.subTest("Assert device name in HTML"):
+                response = self.client.post(self._get_url("bulk_rename"), data)
+                message = (
+                    f"Renaming {len(objects)} {bettertitle(verbose_name_plural)} on {self.selected_objects_parent_name}"
+                )
+                self.assertInHTML(message, response.content.decode(response.charset))
+
+            with self.subTest("Assert update successfully"):
+                data["_apply"] = True  # Form Apply button
+                response = self.client.post(self._get_url("bulk_rename"), data)
+                self.assertHttpStatus(response, 302)
+                queryset = self._get_queryset().filter(pk__in=pk_list)
+                for instance in objects:
+                    self.assertEqual(queryset.get(pk=instance.pk).name, f"{instance.name}X")
+
+            with self.subTest("Assert if no valid objects selected return with error"):
+                for values in ([], [str(uuid.uuid4())]):
+                    data["pk"] = values
+                    response = self.client.post(self._get_url("bulk_rename"), data, follow=True)
+                    expected_message = f"No valid {verbose_name_plural} were selected."
+                    self.assertIn(expected_message, response.content.decode(response.charset))
