@@ -11,11 +11,12 @@ from nautobot.dcim.api.nested_serializers import (
     NestedPlatformSerializer,
     NestedSiteSerializer,
 )
+from nautobot.dcim.api.serializers import InterfaceCommonSerializer
 from nautobot.dcim.choices import InterfaceModeChoices
 from nautobot.extras.api.serializers import (
     NautobotModelSerializer,
     StatusModelSerializerMixin,
-    TaggedObjectSerializer,
+    TaggedModelSerializerMixin,
 )
 from nautobot.extras.api.nested_serializers import NestedConfigContextSchemaSerializer
 from nautobot.extras.models import Status
@@ -79,7 +80,7 @@ class ClusterGroupSerializer(NautobotModelSerializer):
         ]
 
 
-class ClusterSerializer(NautobotModelSerializer, TaggedObjectSerializer):
+class ClusterSerializer(NautobotModelSerializer, TaggedModelSerializerMixin):
     url = serializers.HyperlinkedIdentityField(view_name="virtualization-api:cluster-detail")
     type = NestedClusterTypeSerializer()
     group = NestedClusterGroupSerializer(required=False, allow_null=True)
@@ -111,7 +112,7 @@ class ClusterSerializer(NautobotModelSerializer, TaggedObjectSerializer):
 #
 
 
-class VirtualMachineSerializer(NautobotModelSerializer, TaggedObjectSerializer, StatusModelSerializerMixin):
+class VirtualMachineSerializer(NautobotModelSerializer, TaggedModelSerializerMixin, StatusModelSerializerMixin):
     url = serializers.HyperlinkedIdentityField(view_name="virtualization-api:virtualmachine-detail")
     site = NestedSiteSerializer(read_only=True)
     location = NestedLocationSerializer(read_only=True, required=False, allow_null=True)
@@ -167,7 +168,7 @@ class VirtualMachineWithConfigContextSerializer(VirtualMachineSerializer):
 
 
 # 2.0 TODO: This becomes non-default in 2.0, removed in 2.2.
-class VMInterfaceSerializerVersion12(NautobotModelSerializer, TaggedObjectSerializer):
+class VMInterfaceSerializerVersion12(InterfaceCommonSerializer):
     url = serializers.HyperlinkedIdentityField(view_name="virtualization-api:vminterface-detail")
     virtual_machine = NestedVirtualMachineSerializer()
     mode = ChoiceField(choices=InterfaceModeChoices, allow_blank=True, required=False)
@@ -217,17 +218,6 @@ class VMInterfaceSerializerVersion12(NautobotModelSerializer, TaggedObjectSerial
                 )
 
         # Validate many-to-many VLAN assignments
-        # if self.instance and self.instance.tagged_vlans.exists()
-        mode = data.get("mode", getattr(self.instance, "mode", None))
-        has_tagged_vlans = data.get("tagged_vlans", False)
-        if not has_tagged_vlans and self.instance and self.instance.tagged_vlans.exists():
-            has_tagged_vlans = True
-
-        if has_tagged_vlans and mode != InterfaceModeChoices.MODE_TAGGED:
-            raise serializers.ValidationError(
-                {"tagged_vlans": f"Mode must be set to {InterfaceModeChoices.MODE_TAGGED} when specifying tagged_vlans"}
-            )
-
         virtual_machine = self.instance.virtual_machine if self.instance else data.get("virtual_machine")
         for vlan in data.get("tagged_vlans", []):
             if vlan.site not in [virtual_machine.site, None]:
